@@ -7,6 +7,7 @@ import os
 from abc import ABC, abstractmethod
 from typing import (Any, Deque, Dict, FrozenSet, Generic, Iterable, List,
                     Optional, Sequence, Tuple, TypeVar)
+import warnings
 
 import numpy as np  # type: ignore
 import pandas as pd  # type: ignore
@@ -31,7 +32,7 @@ from ..typehints import IT, KT, DT, RT, LT, VT
 
 LOGGER = logging.getLogger(__name__)
 
-from .rasch_multiple import ModelStatistics
+from ..analysis.statistics import EstimationModelStatistics
 
 def _check_R():
     """Checks if Python <-> R interop is available
@@ -46,7 +47,7 @@ def _check_R():
 
 
 class AbundanceEstimator(AbstractEstimator[IT, KT, DT, VT, RT, LT], Generic[IT, KT, DT, VT, RT, LT]):
-    name = "BestBICEstimator"
+    name = "Mh Chao Estimator"
     def __init__(self):
         self.matrix_history: Deque[pd.DataFrame] = collections.deque()
         self.contingency_history: Deque[Dict[FrozenSet[int], int]] = collections.deque()
@@ -111,12 +112,14 @@ class AbundanceEstimator(AbstractEstimator[IT, KT, DT, VT, RT, LT], Generic[IT,
 
     def calculate_abundance_R(self, estimator: Estimator[Any, KT, DT, VT, RT, LT], 
                               label: LT) -> pd.DataFrame:
-        df = self.get_label_matrix(estimator, label)
-        with localconverter(ro.default_converter + pandas2ri.converter):
-            df_r = ro.conversion.py2rpy(df)
-            abundance_r = ro.globalenv["get_abundance"]
-            r_df = abundance_r(df_r)
-            res_df = ro.conversion.rpy2py(r_df)
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore")
+            df = self.get_label_matrix(estimator, label)
+            with localconverter(ro.default_converter + pandas2ri.converter):
+                df_r = ro.conversion.py2rpy(df)
+                abundance_r = ro.globalenv["get_abundance"]
+                r_df = abundance_r(df_r)
+                res_df: pd.DataFrame = ro.conversion.rpy2py(r_df)
         return res_df
 
     def calculate_abundance(self, 
@@ -136,7 +139,7 @@ class AbundanceEstimator(AbstractEstimator[IT, KT, DT, VT, RT, LT], Generic[IT,
 
     def __call__(self, learner: ActiveLearner[Any, KT, DT, VT, RT, LT], label: LT) -> Estimate:
         empty = np.array([])
-        stats = ModelStatistics(empty, empty, 0.0, empty)
+        stats = EstimationModelStatistics(empty, empty, 0.0, empty)
         if not isinstance(learner, Estimator):
             return Estimate(0.0, 0.0, 0.0)
         estimate = self.calculate_abundance(learner, label)
